@@ -4,6 +4,7 @@ from .exception import PSPException
 from .view import View
 from .aggregate import Aggregate
 from .sort import Sort
+from .filters import ALL_FILTERS
 
 
 def validate_view(view):
@@ -85,7 +86,8 @@ def validate_sort(sort):
         raise PSPException('Cannot parse sort type: %s', str(type(sort)))
 
 
-def validate_computedcolumns(computedcolumns, columns=[]):
+def validate_computedcolumns(computedcolumns, columns=None):
+    columns = columns or []
     if computedcolumns is None:
         return []
 
@@ -97,18 +99,21 @@ def validate_computedcolumns(computedcolumns, columns=[]):
         for i, d in enumerate(computedcolumns):
             if not isinstance(d, dict):
                 raise PSPException('Cannot parse computedcolumns')
+
             if 'inputs' not in d or 'func' not in d:
                 raise PSPException('Cannot parse computedcolumns - inputs or func missing')
+
             if 'name' not in d:
                 d['name'] = 'Anon-{}'.format(i)
 
             inputs = d['inputs']
             if not isinstance(inputs, list):
                 raise PSPException('Cannot parse computedcolumns - inputs is not list')
+
             for i, input in enumerate(inputs):
                 # FIXME check if column exists?
-                if columns and input not in columns:
-                    raise PSPException('Cannot parse computedcolumns - unrecognized column {}'.format(input))
+                # if columns and (input not in columns):
+                #     raise PSPException('Cannot parse computedcolumns - unrecognized column {}'.format(input))
                 if not isinstance(input, string_types):
                     inputs[i] = str(input)
 
@@ -119,3 +124,39 @@ def validate_computedcolumns(computedcolumns, columns=[]):
 
     else:
         raise PSPException('Cannot parse computedcolumns type: %s', str(type(computedcolumns)))
+
+
+def validate_filters(filters, columns=None):
+    columns = columns or []
+    if filters is None:
+        return []
+
+    elif isinstance(filters, list) and len(filters) > 0 and not isinstance(filters[0], list):
+        # wrap
+        filters = [filters]
+
+    if isinstance(filters, list):
+        ret = []
+        for i, d in enumerate(filters):
+            if not isinstance(d, list):
+                raise PSPException('Cannot parse computedcolumns')
+
+            if len(d) != 3:
+                raise PSPException('Cannot parse computedcolumns - unrecognized function {}'.format(d['func']))
+
+            for i, l in enumerate(d):
+                # FIXME check if column exists?
+                # if columns and (l not in columns):
+                #     raise PSPException('Cannot parse computedcolumns - unrecognized column {}'.format(input))
+                if i == 1:
+                    if l not in ALL_FILTERS:
+                        raise PSPException('Unrecognized filter operator: {}'.format(l))
+                pass
+            ret.append(d)
+        return ret
+    else:
+        raise PSPException('Cannot parse filters type: %s', str(type(filters)))
+
+
+def validate_plugin_config(plugin_config):
+    return plugin_config
